---
name: "\U0001F41B Bug report"
about: Create a report to help us improve.
title: "[BUG]"
labels: bug, ml-internal
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Code to reproduce
```python

```

**Expected behaviour**
A clear and concise description of what you expected to happen.

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Desktop (please complete the following information):**
 - Package version:
 - Python version:

**Additional context**
Add any other context about the problem here.
